'use strict';

// eslint-disable-next-line import/no-extraneous-dependencies
var expect = require('chai').expect;
var fs = require('fs-extra');
var path = require('path');
var os = require('os');
var getFeatureList = require('../lib/featureman').getFeatureList;
var getFeatures = require('../lib/featureman').getFeatures;
var tasks = require('./index').tasks;

var skelPath = path.join(__dirname, '../.skel');

// noFlow
describe('getFeatureList', function () {
  // noFlow
  it('Returns list of the names of active features', function () {
    expect(getFeatureList().length).to.equal(0);
    process.env.PRODUCT_DIR = path.join(os.tmpdir(), '_ginjs-test-product');
    fs.copySync(path.join(skelPath, 'product'), process.env.PRODUCT_DIR);
    // eslint-disable-next-line no-unused-expressions
    expect(getFeatureList()[0]).to.equal('ginjs');
    // eslint-disable-next-line no-unused-expressions
    expect(getFeatureList()[1]).to.equal('gap');
    fs.removeSync(process.env.PRODUCT_DIR);
    delete process.env.PRODUCT_DIR;
    Object.keys(require.cache).forEach(function (elem) {
      delete require.cache[elem];
    });
  });
});

describe('getFeatures', function () {
  // noFlow
  it('Returns list of active features', function () {
    process.env.PRODUCTLINE_DIR = path.join(os.tmpdir(), '_ginjs-test-productline');
    process.env.PATH = process.env.PATH;
    process.env.PATH = process.env.PRODUCTLINE_DIR + '/node_modules/.bin:' + (process.env.PATH || '');
    process.env.NODE_PATH = process.env.PRODUCTLINE_DIR + '/features:' + process.env.PRODUCTLINE_DIR + '/node_modules:' + (process.env.NODE_PATH || '');
    // To be sure new NODE_PATH is used:
    // noFlow
    require('module').Module._initPaths(); // eslint-disable-line no-underscore-dangle, global-require

    process.chdir(os.tmpdir());
    tasks.createProductLine('_ginjs-test-productline');
    process.env.PRODUCT_DIR = path.join(process.env.PRODUCTLINE_DIR || '', 'products', 'default');
    // noFlow
    var gap = require('gap'); // eslint-disable-line import/no-unresolved, global-require, import/no-extraneous-dependencies

    fs.writeJSONSync(path.join(process.env.PRODUCT_DIR || '', 'features.json'), ['./index', // to ensure ginjs is just loaded once through path
    'gap']);
    var featureList = getFeatures();
    // eslint-disable-next-line no-unused-expressions
    expect(gap === featureList[1]).to.be.true;
    fs.removeSync(process.env.PRODUCTLINE_DIR);
    delete process.env.PRODUCTLINE_DIR;
    delete process.env.PRODUCT_DIR;
    Object.keys(require.cache).forEach(function (elem) {
      delete require.cache[elem];
    });
  });
});